Tutorials
=========
Here we link you to some tutorial resources for aiida-fleur and related topics.
In general you find hands-on tutorial material under https://github.com/JuDFTteam/judft_tutorials 
and in the examples folder of the aiida-fleur package (the examples lack sometimes behind). 

AiiDA tutorials
---------------
If you are not familiar with the basics of AiiDA yet, you might want to checkout
the `AiiDA youtube tutorials. <https://www.youtube.com/channel/UC-NZvRRQ5VzT2wKE5DM1N3A/playlists>`_
The jupyter notebooks from the tutorials you will find `here on github <https://github.com/aiidateam/aiida_demos>`_,
where you can also try them out in binder.
Virtual machines for tutorials and tutorial manuals you `find here <http://www.aiida.net/tutorials/>`_.

An introduction video into AiiDA you find `here <https://www.youtube.com/watch?v=jigMCyWGNAE>`_
or other videos under the `Materials cloud channel <https://www.youtube.com/channel/UC-NZvRRQ5VzT2wKE5DM1N3A>`_.

AiiDA-FLEUR tutorials
---------------------
Lectures:
- Introduction into `AiiDA-fleur <https://www.youtube.com/watch?v=qPVWA2motO4>`_
- Introduction into `AiiDA-fleur workflows <https://www.youtube.com/watch?v=2BVrZ4siJNg>`_ 

Hands on:
- The Hands-on session from a `tutorial in 04.2021 <https://github.com/JuDFTteam/judft_tutorials/tree/master/tutorials/aiida_fleur_workshop_2021>`_.

FLEUR & FLAPW tutorials
-----------------------
In general for new, documentation and tutorials for the FLEUR program checkout 
www.flapw.de. 

Videos and pdfs from a tutorial in 2021:
https://www.flapw.de/MaX-5.1/video/
